Package: RPhosFate
Type: Package
Title: Soil and Chemical Substance Emission and Transport Model
Version: 2.0.1
Authors@R: person("Gerold", "Hepp", email = "gisler@hepp.cc", role = c("aut", "cre"))
Description: An enhanced version of the semi-empirical, spatially distributed
    emission and transport model PhosFate implemented in 'R' and 'C++'. It is 
    based on the D-infinity, but also supports the D8 flow method. The currently
    available substances are suspended solids (SS) and particulate phosphorus 
    (PP). A major feature is the allocation of substance loads entering surface 
    waters to their sources of origin, which is a basic requirement for the 
    identification of critical source areas and in consequence a cost-effective
    implementation of mitigation measures. References: Hepp et al. (2022)
    <doi:10.1016/j.jenvman.2022.114514>; Hepp and Zessner (2019)
    <doi:10.3390/w11102161>; Kovacs (2013)
    <http://hdl.handle.net/20.500.12708/9468>.
License: AGPL (>= 3)
URL: https://gisler.github.io/RPhosFate/
BugReports: https://github.com/gisler/RPhosFate/issues
Language: en-GB
Encoding: UTF-8
ByteCompile: true
Depends: R (>= 3.5.0)
Imports: checkmate, graphics, methods, Rcpp, stats, terra, tools,
        utils, yaml
Suggests: knitr, rmarkdown, tinytest, whitebox (>= 2.0.0)
LinkingTo: Rcpp, RcppArmadillo
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Collate: 'GOFmetrics.R' 'aaa.R' 'RPhosFate.R' 'RcppExports.R'
        'assertives.R' 'gettersSetters.R' 'input.R' 'interface.R'
        'utils.R' 'zzz.R'
NeedsCompilation: yes
Packaged: 2025-03-22 10:15:59 UTC; ghepp
Author: Gerold Hepp [aut, cre]
Maintainer: Gerold Hepp <gisler@hepp.cc>
Repository: CRAN
Date/Publication: 2025-03-22 10:40:04 UTC
Built: R 4.3.3; aarch64-apple-darwin20; 2025-03-22 12:29:22 UTC; unix
Archs: RPhosFate.so.dSYM
