# Generated by roxygen2: do not edit by hand

export(DEMrelatedInput)
export(RPhosFate)
export(autoCalibrate)
export(autoCalibrate2)
export(calibrationQuality)
export(catchment)
export(demoProject)
export(emission)
export(erosion)
export(erosionPrerequisites)
export(firstRun)
export(getLayer)
export(getParameter)
export(img2tif)
export(saveState)
export(setParameter)
export(snapGauges)
export(subsequentRun)
export(transport)
export(transportPrerequisites)
exportClasses(RPhosFate)
exportMethods("[")
exportMethods(autoCalibrate)
exportMethods(autoCalibrate2)
exportMethods(calibrationQuality)
exportMethods(emission)
exportMethods(erosion)
exportMethods(erosionPrerequisites)
exportMethods(firstRun)
exportMethods(getLayer)
exportMethods(getParameter)
exportMethods(saveState)
exportMethods(setParameter)
exportMethods(snapGauges)
exportMethods(subsequentRun)
exportMethods(transport)
exportMethods(transportPrerequisites)
import(checkmate)
import(methods)
import(terra)
importFrom(Rcpp,sourceCpp)
importFrom(graphics,abline)
importFrom(graphics,clip)
importFrom(graphics,par)
importFrom(stats,cor)
importFrom(stats,optim)
importFrom(stats,optimize)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(utils,modifyList)
importFrom(utils,packageVersion)
importFrom(yaml,read_yaml)
importFrom(yaml,write_yaml)
useDynLib(RPhosFate, .registration = TRUE)
